@@ -69,9 +69,9 @@ class ValidatedJSONField(JSONField):
 
         self.isArray = False
         if(self.schema is not None):
-            if(default==list or default==[] or self.schema.get("type","").lower()=="array"):
+            if(default==list or default==[] or str(self.schema.get("type","")).lower()=="array"):
                 self.isArray=True
-            elif(default==dict or default=={} or self.schema.get("type","").lower()=="object"):
+            elif(default==dict or default=={} or str(self.schema.get("type","")).lower()=="object"):
                 self.isArray=False
             elif(default is not None):
                 print("#WARNING# ValidatedJSONField: default argument is not allowed, as default is taken from schema", default)
